==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicSpinnerUI__243.h <==
// final class javax.swing.plaf.basic.BasicSpinnerUI$3

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ce44dfb4fddb3336 javax_swing_plaf_basic_BasicSpinnerUI__243

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSpinnerUI__243_H_
#define _JC_javax_swing_plaf_basic_BasicSpinnerUI__243_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Timer$object;
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$_init$17b8739b949036dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$increment$d5cdea57b85439c6(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *);
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$increment$d5cdea57b85439c6;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods {
	void	(*increment$d5cdea57b85439c6)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods	javax_swing_plaf_basic_BasicSpinnerUI__243;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs {
	struct _jc_javax_swing_Timer$object	*timer;
	struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs {
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs	javax_swing_plaf_basic_BasicSpinnerUI__243;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs {
	jboolean	volatile mouseDown;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs	javax_swing_plaf_basic_BasicSpinnerUI__243;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object {
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSpinnerUI__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSpinnerUI__243_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicSpinnerUI__243.h <==
// final class javax.swing.plaf.basic.BasicSpinnerUI$3

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ce44dfb4fddb3336 javax_swing_plaf_basic_BasicSpinnerUI__243

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSpinnerUI__243_H_
#define _JC_javax_swing_plaf_basic_BasicSpinnerUI__243_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Timer$object;
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$_init$17b8739b949036dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$increment$d5cdea57b85439c6(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$increment$d5cdea57b85439c6;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods {
	void	(*increment$d5cdea57b85439c6)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vmethods	javax_swing_plaf_basic_BasicSpinnerUI__243;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs {
	struct _jc_javax_swing_Timer$object	*timer;
	struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs {
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_refs	javax_swing_plaf_basic_BasicSpinnerUI__243;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs {
	jboolean	volatile mouseDown;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$sub_nonrefs	javax_swing_plaf_basic_BasicSpinnerUI__243;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$object {
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$vtype _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSpinnerUI__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSpinnerUI__243$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSpinnerUI__243_H_ */
